@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0906';
+our $VERSION = '0.0907';
 
 use v5.36;
 
@@ -137,7 +137,8 @@ sub single ($self, $device, $dt, $event) {
     my $value = $self->value || $val;
     my $cc = [ 'control_change', $self->channel, $self->control, $value ];
     $self->rtc->send_it($cc);
-    return 1;
+
+    return 0;
 }
 
 
@@ -332,7 +333,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0906
+version 0.0907
 
 =head1 SYNOPSIS
 
@@ -366,6 +367,9 @@ control-change based L<MIDI::RtController> filters.
 Passing C<all> to the C<add_filter> method means that any MIDI event
 will trigger the filter.
 
+In order to stop a running filter, send a C<CTRL-C> to the console...
+Halting midstream, with logic, is not yet happening.
+
 =head2 Making filters
 
 All filter methods must accept the object, a MIDI device name, a
@@ -524,12 +528,12 @@ example:
 
   [
     { # mod-wheel
-      port => 'keyboard',        # what is controlling it
+      port => 'keyboard',        # what device is controlling
       type => 'breathe',         # the type of filter
       event => 'control_change', # or [qw(note_on note_off)] etc
       control => 1,              # what CC# is being controlled
       trigger => 25,             # what CC# triggers the controlling
-      time_step => 0.25,         # a parameter
+      time_step => 0.25,         # a module attribute parameter
     },
     ...
   ]
@@ -549,7 +553,7 @@ MIDI input device port names.
   $control->add_filter('single', all => $filter->curry::single);
 
 This filter sets a single B<control> change message, over the MIDI
-B<channel> once.
+B<channel>.
 
 If B<trigger> is set, the filter checks that against the MIDI event
 C<note> to see if the filter should be applied.
